import { Component, Injector, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AppConsts } from '@shared/AppConsts';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { ProximityListDto, ProximityServiceProxy } from '@shared/service-proxies/service-proxies';
import { FileDownloadService } from '@shared/utils/file-download.service';
import * as moment from 'moment';
import { LazyLoadEvent } from 'primeng/components/common/lazyloadevent';
import { Paginator } from 'primeng/components/paginator/paginator';
import { Table } from 'primeng/components/table/table';
import { HttpClient } from '@angular/common/http';
import { FileUpload } from 'primeng/fileupload';
import { finalize } from 'rxjs/operators';
import { CreateProximityModalComponent } from './create-proximity-modal.component';
import * as _ from 'lodash';
@Component({
    templateUrl: 'proximity.component.html',
    encapsulation: ViewEncapsulation.None,
    animations: [appModuleAnimation()]
})

export class ProximityComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable', {static: true}) dataTable: Table;
    @ViewChild('paginator', {static: true}) paginator: Paginator;
    @ViewChild('createProximityModal', {static: false}) createProximityModal: CreateProximityModalComponent;
  

    
    filters: {
        id: number;
        value: number;
        CurrentPage: number;
    } = <any>{};



    constructor(
        injector: Injector,
        private _proximityService: ProximityServiceProxy
    ) {
        super(injector);
    }

    ngOnInit(): void {

    }

    getProximities(event?: LazyLoadEvent) {
          
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        this.spinnerService.show();
        this._proximityService.getProximity(
            this.filters.id,
            undefined,
            undefined,
            this.filters.value,
            this.primengTableHelper.getSorting(this.dataTable),
            this.primengTableHelper.getMaxResultCount(this.paginator, event),
            this.primengTableHelper.getSkipCount(this.paginator, event)
        ).pipe(finalize(() => this.spinnerService.hide())).subscribe(result => {
            this.primengTableHelper.totalRecordsCount = result.totalCount;
            this.primengTableHelper.records = result.items;
            this.spinnerService.hide();
        });

    }

    createProximity(): void {
        this.createProximityModal.show();
    }

    reloadPage(): void {
        this.paginator.changePage(this.paginator.getPage());
    }

    deleteProximity(proximity: ProximityListDto): void {
    this.message.confirm(
        this.l('Delete Proximity'),
        isConfirmed => {
            if (isConfirmed) {
                this._proximityService.deleteProximity(proximity.id).subscribe(() => {
                    this.reloadPage();
                    this.notify.info(this.l('SuccessfullyDeleted'));
                    
                });
                
            }
        }
      );
    } 

 

    
   

}
