import { Component, Injector, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AppConsts } from '@shared/AppConsts';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { VehicleLocationListDto, VehicleLocationServiceProxy } from '@shared/service-proxies/service-proxies';
import { FileDownloadService } from '@shared/utils/file-download.service';
import * as moment from 'moment';
import { LazyLoadEvent } from 'primeng/components/common/lazyloadevent';
import { Paginator } from 'primeng/components/paginator/paginator';
import { Table } from 'primeng/components/table/table';
import { HttpClient } from '@angular/common/http';
import { FileUpload } from 'primeng/fileupload';
import { finalize } from 'rxjs/operators';
import { CreateVehicleLocationModalComponent } from './create-vehicle-location-modal.component';

import * as _ from 'lodash';
@Component({
    templateUrl: 'vehicle-location.component.html',
    encapsulation: ViewEncapsulation.None,
    animations: [appModuleAnimation()]
})

export class VehicleLocationComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable', {static: true}) dataTable: Table;
    @ViewChild('paginator', {static: true}) paginator: Paginator;
    @ViewChild('createVehicleLocationModal', {static: false}) createVehicleLocationModal: CreateVehicleLocationModalComponent;
    

    
    filters: {
        id: number;
        vehicleId: number;
        locationId: number;
        vehicle: string;
        CurrentPage: number;
    } = <any>{};


    vehicleLocation : VehicleLocationListDto;
    constructor(
        injector: Injector,
        private _vehicleLocationService: VehicleLocationServiceProxy
       
    ) {
        super(injector);
    }

    ngOnInit(): void {

    }

    getVehicleLocations(event?: LazyLoadEvent) {
          
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        this.spinnerService.show();
        this._vehicleLocationService.getVehicleLocation(
            this.filters.id,
            this.filters.vehicleId,
            this.filters.locationId,
            this.filters.vehicle,
            this.primengTableHelper.getSorting(this.dataTable),
            this.primengTableHelper.getMaxResultCount(this.paginator, event),
            this.primengTableHelper.getSkipCount(this.paginator, event)
        ).pipe(finalize(() => this.spinnerService.hide())).subscribe(result => {
            this.primengTableHelper.totalRecordsCount = result.totalCount;
            this.primengTableHelper.records = result.items;
            this.spinnerService.hide();
            console.log(result.items);
        });



    }

     
   createVehicleLocation(): void {
        this.createVehicleLocationModal.show();
    }

    

    reloadPage(): void {
        this.paginator.changePage(this.paginator.getPage());
    }
    
   deleteVehicleLocation(vehicleLocation): void {
    this.message.confirm(
        this.l('Delete Vehicle Location'),
        isConfirmed => {
            if (isConfirmed) {
                this._vehicleLocationService.deleteVehicleLocation(vehicleLocation).subscribe(() => {
                    this.reloadPage();
                    this.notify.info(this.l('Successfully Deleted'));
                    
                });
                
            }
        }
      );
    } 

}
