import { Component, Injector, OnInit, ViewChild, ViewEncapsulation } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { AppConsts } from '@shared/AppConsts';
import { appModuleAnimation } from '@shared/animations/routerTransition';
import { AppComponentBase } from '@shared/common/app-component-base';
import { RouteTemplateTypeListDto, RouteTemplateTypeServiceProxy } from '@shared/service-proxies/service-proxies';

import * as moment from 'moment';
import { LazyLoadEvent } from 'primeng/components/common/lazyloadevent';
import { Paginator } from 'primeng/components/paginator/paginator';
import { Table } from 'primeng/components/table/table';
import { HttpClient } from '@angular/common/http';
import { finalize } from 'rxjs/operators';
import { CreateRouteTemplateTypeModalComponent } from './create-route-template-types-modal.component';
import * as _ from 'lodash';
@Component({
    templateUrl: 'route-template-types.component.html',
    encapsulation: ViewEncapsulation.None,
    animations: [appModuleAnimation()]
})

export class RouteTemplateTypesComponent extends AppComponentBase implements OnInit {

    @ViewChild('dataTable', {static: true}) dataTable: Table;
    @ViewChild('paginator', {static: true}) paginator: Paginator;
    @ViewChild('createRouteTemplateTypeModal', {static: false}) createRouteTemplateTypeModal: CreateRouteTemplateTypeModalComponent;

    
    
    filters: {
        id: number;
        name: string;
        
    } = <any>{};

    constructor(
        injector: Injector,
        private _routeTemplateTypeService: RouteTemplateTypeServiceProxy
        
    ) {
        super(injector);
    }

    ngOnInit(): void {

    }

    getRouteTemplateTypes(event?: LazyLoadEvent) {
          
        if (this.primengTableHelper.shouldResetPaging(event)) {
            this.paginator.changePage(0);
            return;
        }
        this.spinnerService.show();
        this._routeTemplateTypeService.getRouteTemplateType(
            this.filters.id,
            this.filters.name,
            this.primengTableHelper.getSorting(this.dataTable),
            this.primengTableHelper.getMaxResultCount(this.paginator, event),
            this.primengTableHelper.getSkipCount(this.paginator, event)
        ).pipe(finalize(() => this.spinnerService.hide())).subscribe(result => {
            this.primengTableHelper.totalRecordsCount = result.totalCount;
            this.primengTableHelper.records = result.items;
            this.spinnerService.hide();
            
                        

            //console.log(this.incidentId.id);
            
        });

    }

 

    
    createRouteTemplateType(): void {
        this.createRouteTemplateTypeModal.show();
    }
    

    reloadPage(): void {
        this.paginator.changePage(this.paginator.getPage());
    }

    deleteRouteTemplateType(routeTemplateType: RouteTemplateTypeListDto): void {
            
        console.log(routeTemplateType);

        this.message.confirm(
            this.l('RouteTemplateTypeWarningMessage', routeTemplateType.name),
            this.l('AreYouSure'),
            (isConfirmed) => {
                if (isConfirmed) {
                    this._routeTemplateTypeService.deleteRouteTemplateType(routeTemplateType.id).subscribe(() => {
                        this.reloadPage();
                        this.notify.info(this.l('SuccessfullyDeleted'));
                        
                    });
                }
            }
        );
    } 


    
 

    
   

}
